# automatically generated file, don't edit
package Number::Phone::Data;
*Number::Phone::libphonenumber_tag = sub { "v8.13.7" };
*Number::Phone::UK::data_source = sub { "OFCOM at ".gmtime(1677671489)." UTC" };
*Number::Phone::NANP::CA::data_source = sub { "CNAC at ".gmtime(1678136456)." UTC" };
*Number::Phone::NANP::US::data_source = sub { "National Pooling Administrator at ".gmtime(1678173486)." UTC" };
*Number::Phone::NANP::data_source = sub { "localcallingguide.com at ".gmtime(1678212848)." UTC" };
1;

=head1 NAME

Number::Phone::Data

=head1 DATA SOURCES

Canadian operator data derived from CNAC at Mon Mar 6 21:00:56 2023 UTC

US operator data derived from National Pooling Administrator at Tue Mar 7 07:18:06 2023 UTC

Other NANP operator data derived from localcallingguide.com at Tue Mar 7 18:14:08 2023 UTC

UK data derived from OFCOM at Wed Mar 1 11:51:29 2023 UTC

Most other data derived from libphonenumber v8.13.7

=cut
